pub struct SqliteRevocationStore { /* private fields */ }Implementations
Sourceimpl SqliteRevocationStore
impl SqliteRevocationStore
pub fn open(path: impl AsRef<Path>) -> Result<Self, RevocationStoreError>
pub fn latest_revocation_index(&self) -> Result<u64, RevocationStoreError>
pub fn list_revocations( &self, limit: usize, capability_id: Option<&str>, ) -> Result<Vec<RevocationRecord>, RevocationStoreError>
pub fn list_revocations_after( &self, limit: usize, after_revoked_at: Option<i64>, after_capability_id: Option<&str>, ) -> Result<Vec<RevocationRecord>, RevocationStoreError>
pub fn upsert_revocation( &self, record: &RevocationRecord, ) -> Result<(), RevocationStoreError>
Sourcepub fn latest_revocation_cursor(
&self,
) -> Result<Option<(i64, String)>, RevocationStoreError>
pub fn latest_revocation_cursor( &self, ) -> Result<Option<(i64, String)>, RevocationStoreError>
The head of the revocation stream as the pagination cursor tuple (revoked_at, capability_id), or None when empty. list_revocations_after paginates ascending, so the head is the descending row.